module.exports=['\uFDD0','\uFDD1','\uFDD2','\uFDD3','\uFDD4','\uFDD5','\uFDD6','\uFDD7','\uFDD8','\uFDD9','\uFDDA','\uFDDB','\uFDDC','\uFDDD','\uFDDE','\uFDDF','\uFDE0','\uFDE1','\uFDE2','\uFDE3','\uFDE4','\uFDE5','\uFDE6','\uFDE7','\uFDE8','\uFDE9','\uFDEA','\uFDEB','\uFDEC','\uFDED','\uFDEE','\uFDEF','\uFFFE','\uFFFF','\uD83F\uDFFE','\uD83F\uDFFF','\uD87F\uDFFE','\uD87F\uDFFF','\uD8BF\uDFFE','\uD8BF\uDFFF','\uD8FF\uDFFE','\uD8FF\uDFFF','\uD93F\uDFFE','\uD93F\uDFFF','\uD97F\uDFFE','\uD97F\uDFFF','\uD9BF\uDFFE','\uD9BF\uDFFF','\uD9FF\uDFFE','\uD9FF\uDFFF','\uDA3F\uDFFE','\uDA3F\uDFFF','\uDA7F\uDFFE','\uDA7F\uDFFF','\uDABF\uDFFE','\uDABF\uDFFF','\uDAFF\uDFFE','\uDAFF\uDFFF','\uDB3F\uDFFE','\uDB3F\uDFFF','\uDB7F\uDFFE','\uDB7F\uDFFF','\uDBBF\uDFFE','\uDBBF\uDFFF']