module.exports=/[ij\u012F\u0249\u0268\u029D\u02B2\u03F3\u0456\u0458\u1D62\u1D96\u1DA4\u1DA8\u1E2D\u1ECB\u2071\u2148\u2149\u2C7C]|\uD835[\uDC22\uDC23\uDC56\uDC57\uDC8A\uDC8B\uDCBE\uDCBF\uDCF2\uDCF3\uDD26\uDD27\uDD5A\uDD5B\uDD8E\uDD8F\uDDC2\uDDC3\uDDF6\uDDF7\uDE2A\uDE2B\uDE5E\uDE5F\uDE92\uDE93]/