module.exports=['\uD82F\uDCA0','\uD82F\uDCA1','\uD82F\uDCA2','\uD82F\uDCA3','\uD82F\uDCA4','\uD82F\uDCA5','\uD82F\uDCA6','\uD82F\uDCA7','\uD82F\uDCA8','\uD82F\uDCA9','\uD82F\uDCAA','\uD82F\uDCAB','\uD82F\uDCAC','\uD82F\uDCAD','\uD82F\uDCAE','\uD82F\uDCAF']