module.exports=['\uD81B\uDFE0','\uD81B\uDFE1','\uD81B\uDFE2','\uD81B\uDFE3','\uD81B\uDFE4','\uD81B\uDFE5','\uD81B\uDFE6','\uD81B\uDFE7','\uD81B\uDFE8','\uD81B\uDFE9','\uD81B\uDFEA','\uD81B\uDFEB','\uD81B\uDFEC','\uD81B\uDFED','\uD81B\uDFEE','\uD81B\uDFEF','\uD81B\uDFF0','\uD81B\uDFF1','\uD81B\uDFF2','\uD81B\uDFF3','\uD81B\uDFF4','\uD81B\uDFF5','\uD81B\uDFF6','\uD81B\uDFF7','\uD81B\uDFF8','\uD81B\uDFF9','\uD81B\uDFFA','\uD81B\uDFFB','\uD81B\uDFFC','\uD81B\uDFFD','\uD81B\uDFFE','\uD81B\uDFFF']