module.exports=/[\u09BE\u09D7\u0B3E\u0B57\u0BBE\u0BD7\u0CC2\u0CD5\u0CD6\u0D3E\u0D57\u0DCF\u0DDF\u200C\u302E\u302F\uFF9E\uFF9F]|\uD804[\uDF3E\uDF57]|\uD805[\uDCB0\uDCBD\uDDAF]|\uD834[\uDD65\uDD6E-\uDD72]|\uDB40[\uDC20-\uDC7F]/