module.exports=['\uAAE0','\uAAE1','\uAAE2','\uAAE3','\uAAE4','\uAAE5','\uAAE6','\uAAE7','\uAAE8','\uAAE9','\uAAEA','\uAAEB','\uAAEC','\uAAED','\uAAEE','\uAAEF','\uAAF0','\uAAF1','\uAAF2','\uAAF3','\uAAF4','\uAAF5','\uAAF6','\uAAF7','\uAAF8','\uAAF9','\uAAFA','\uAAFB','\uAAFC','\uAAFD','\uAAFE','\uAAFF']