module.exports=/[\u094D\u09CD\u0A4D\u0ACD\u0B4D\u0BCD\u0C4D\u0CCD\u0D4D\u0DCA\u0E3A\u0F84\u1039\u103A\u1714\u1734\u17D2\u1A60\u1B44\u1BAA\u1BAB\u1BF2\u1BF3\u2D7F\uA806\uA8C4\uA953\uA9C0\uAAF6\uABED]|\uD802\uDE3F|\uD804[\uDC46\uDC7F\uDCB9\uDD33\uDD34\uDDC0\uDE35\uDEEA\uDF4D]|\uD805[\uDC42\uDCC2\uDDBF\uDE3F\uDEB6\uDF2B]|\uD807\uDC3F/